==> ATutor-1.5.3.tar.gz: ATutor/documentation/common/text.php <==
<?php

$text['next_chapter'] = 'Next Chapter';
$text['previous_chapter'] = 'Previous Chapter';
$text['page_not_translated'] = 'This page has not yet been translated to that language.';
$text['atutor_documentation'] = 'ATutor Documentation';
$text['handbook_toc'] = 'Handbook TOC';
$text['close_popup'] = 'Close Pop-up';
$text['return_to_handbook'] = 'Return to Handbook';
$text['print_version'] = 'Print Version';
$text['show_contents'] = 'Show Contents';
$text['hide_contents'] = 'Hide Contents';
$text['language']      = 'Language';
$text['search']        = 'Search';
$text['back_to_contents'] = 'Back to Contents';
$text['no_results_found'] = 'No results found.';
$text['search_term_longer_3_chars'] = 'Search term must be longer than 3 characters.';
$text['doc_user'] = 'User Documentation';
$text['doc_admin'] = 'Administrator Documentation';
$text['doc_dev'] = 'Developer Documentation';
$text['doc_instructor'] = 'Instructor Documentation';
$text['doc_mods'] = 'Module Development Documentation';
$text['doc_notes_enabled'] = 'User contributed notes is <em>enabled</em>. <a href="index_list.php?login">Administrator Login</a>.';
$text['doc_title'] = 'ATutor 1.5.3 Documentation';
$text['doc_welcome'] = 'Welcome to the official ATutor Handbook!';
$text['doc_unapproved_notes'] = 'Un-Approved User Contributed Notes';
$text['doc_approved_confirm'] = 'Are you sure you want to approve this note?';
$text['doc_approve'] = 'Approve';
$text['doc_delete'] = 'Delete';
$text['doc_delete_confirm'] = 'Are you sure you want to delete this note?';
$text['doc_no_notes'] = 'There are no un-approved user contributed notes.';
$text['doc_logged_in'] = 'Logged in as notes moderator. <a href="index_list.php?logout">Log-out</a>.';
$text['user_contributed_notes'] = 'User Contributed Notes';
$text['no_notes_on_page'] = 'There are no user contributed notes for this page.';
$text['delete'] = 'Delete';
$text['are_you_sure_delete_note'] = 'Are you sure you want to delete this note?';
$text['add_note'] = 'Add Note';
$text['add_note_blurb'] = 'If you ask a question, report a bug, or request a feature, your note will not be posted. Notes must be approved by an administrator before they are posted.';
$text['email_name'] = 'Your email address (or name)';
$text['your_note'] = 'Your note';
?>

==> ATutor-1.6.tar.gz: ATutor/documentation/common/text.php <==
<?php
$text = array();
$text['next_chapter'] = 'Next Chapter';
$text['previous_chapter'] = 'Previous Chapter';
$text['page_not_translated'] = 'This section has not yet been translated to your requested language.';
$text['atutor_documentation'] = 'ATutor Handbook';
$text['handbook_toc'] = 'Handbook TOC';
$text['close_popup'] = 'Close Pop-up';
$text['return_to_handbook'] = 'Return to Handbook';
$text['print_version'] = 'Print Version';
$text['show_contents'] = 'Show Contents';
$text['hide_contents'] = 'Hide Contents';
$text['language']      = 'Language';
$text['search']        = 'Search';
$text['back_to_contents'] = 'Back to Contents';
$text['no_results_found'] = 'No results found.';
$text['search_term_longer_3_chars'] = 'Search term must be longer than 3 characters.';
$text['doc_user'] = 'User Documentation';
$text['doc_admin'] = 'Administrator Documentation';
$text['doc_dev'] = 'Developer Documentation';
$text['doc_instructor'] = 'Instructor Documentation';
$text['doc_mods'] = 'Module Development Documentation';
$text['doc_notes_enabled'] = 'User contributed notes is <em>enabled</em>. <a href="index.php?login">Administrator Login</a>.';
$text['doc_title'] = 'ATutor Handbook';
$text['doc_welcome'] = 'Welcome to the official ATutor Handbook!';
$text['doc_unapproved_notes'] = 'Un-Approved User Contributed Notes';
$text['doc_approved_confirm'] = 'Are you sure you want to approve this note?';
$text['doc_approve'] = 'Approve';
$text['doc_delete'] = 'Delete';
$text['doc_delete_confirm'] = 'Are you sure you want to delete this note?';
$text['doc_no_notes'] = 'There are no un-approved user contributed notes.';
$text['doc_logged_in'] = 'Logged in as notes moderator. <a href="index.php?logout">Log-out</a>.';
$text['user_contributed_notes'] = 'User Contributed Notes';
$text['no_notes_on_page'] = 'There are no user contributed notes for this page.';
$text['delete'] = 'Delete';
$text['are_you_sure_delete_note'] = 'Are you sure you want to delete this note?';
$text['add_note'] = 'Add Note';
$text['add_note_blurb'] = 'If you ask a question, report a bug, or request a feature, your note will not be posted. Notes must be approved by an administrator before they are posted.';
$text['email_name'] = 'Your email address (or name)';
$text['your_note'] = 'Your note';
$text['note_added'] = 'Your note has been saved. It will appear only after it has been approved by an administrator.';
$text['back_to_chapters'] = 'Back to Chapters';
?>
